==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/xml/xpath/Libxml2ExtensionHandle.hpp <==
#ifndef _COM_SUN_STAR_XML_XPATH_LIBXML2EXTENSIONHANDLE_HPP_
#define _COM_SUN_STAR_XML_XPATH_LIBXML2EXTENSIONHANDLE_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_XML_XPATH_LIBXML2EXTENSIONHANDLE_HDL_
#include "com/sun/star/xml/xpath/Libxml2ExtensionHandle.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace xml { namespace xpath {

inline Libxml2ExtensionHandle::Libxml2ExtensionHandle() SAL_THROW( () )
    : functionLookupFunction(0)
    , functionData(0)
    , variableLookupFunction(0)
    , variableData(0)
{
}

inline Libxml2ExtensionHandle::Libxml2ExtensionHandle(const ::sal_Int64& functionLookupFunction_, const ::sal_Int64& functionData_, const ::sal_Int64& variableLookupFunction_, const ::sal_Int64& variableData_) SAL_THROW( () )
    : functionLookupFunction(functionLookupFunction_)
    , functionData(functionData_)
    , variableLookupFunction(variableLookupFunction_)
    , variableData(variableData_)
{
}

} } } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::xml::xpath::Libxml2ExtensionHandle const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.xml.xpath.Libxml2ExtensionHandle");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_XML_XPATH_LIBXML2EXTENSIONHANDLE_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/xml/xpath/Libxml2ExtensionHandle.hpp <==
#ifndef _COM_SUN_STAR_XML_XPATH_LIBXML2EXTENSIONHANDLE_HPP_
#define _COM_SUN_STAR_XML_XPATH_LIBXML2EXTENSIONHANDLE_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_XML_XPATH_LIBXML2EXTENSIONHANDLE_HDL_
#include "com/sun/star/xml/xpath/Libxml2ExtensionHandle.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace xml { namespace xpath {

inline Libxml2ExtensionHandle::Libxml2ExtensionHandle() SAL_THROW( () )
    : functionLookupFunction(0)
    , functionData(0)
    , variableLookupFunction(0)
    , variableData(0)
{
}

inline Libxml2ExtensionHandle::Libxml2ExtensionHandle(const ::sal_Int64& functionLookupFunction_, const ::sal_Int64& functionData_, const ::sal_Int64& variableLookupFunction_, const ::sal_Int64& variableData_) SAL_THROW( () )
    : functionLookupFunction(functionLookupFunction_)
    , functionData(functionData_)
    , variableLookupFunction(variableLookupFunction_)
    , variableData(variableData_)
{
}

} } } } }

namespace com { namespace sun { namespace star { namespace xml { namespace xpath {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::xml::xpath::Libxml2ExtensionHandle const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.xml.xpath.Libxml2ExtensionHandle");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::xml::xpath::Libxml2ExtensionHandle const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::xml::xpath::Libxml2ExtensionHandle >::get();
}

#endif // _COM_SUN_STAR_XML_XPATH_LIBXML2EXTENSIONHANDLE_HPP_
